==> IJPay-1.1.6-javadoc.jar: README.md <==
# IJPay

![](assets/img/IJPay-t.png)

[![Gitee star](https://gitee.com/javen205/IJPay/badge/star.svg?theme=white)](https://gitee.com/javen205/IJPay/stargazers)
[![Github start](https://img.shields.io/github/stars/Javen205/IJPay.svg?style=social&label=Stars)](https://github.com/Javen205/IJPay)
[![License][licensesvg]][license]
[![Github downloads](https://img.shields.io/github/downloads/Javen205/IJPay/total.svg)](https://github.com/Javen205/IJPay/releases/latest)
[![IJPay Author](https://img.shields.io/badge/IJPay%20Author-Javen-ff69b4.svg)](http://blog.csdn.net/zyw_java)
[![GitHub release](https://img.shields.io/github/release/Javen205/IJPay.svg)](https://github.com/Javen205/IJPay/release)
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/com.github.javen205/IJPay/badge.svg)](https://maven-badges.herokuapp.com/maven-central/com.github.javen205/IJPay)


**特别说明：** 不依赖任何第三方 mvc 框架，仅仅作为工具使用简单快速完成支付模块的开发，可轻松嵌入到任何系统里。

**微信群在线交流活动** [点击这里查看详情](https://github.com/Javen205/IJPay/wiki)

Gitee：[http://gitee.com/Javen205/IJPay](http://gitee.com/Javen205/IJPay)

GitHub：[https://github.com/Javen205/IJPay](https://github.com/Javen205/IJPay)




- IJPay是[JPay](https://github.com/Javen205/JPay)后台接口SDK不依赖任何第三方 mvc 框架，仅仅作为工具使用简单快速完成支付模块的开发，可轻松嵌入到任何系统里。
- [JPay](https://github.com/Javen205/JPay) 是简易而不简单的Android 支付SDK，JPay是对微信App支付、支付宝App支付的二次封装,对外提供一个相对简单的接口以及支付结果的回调。
- IOS支付SDK，敬请关注。

### 接入文档

[GitBook 接入文档欢迎订阅，如有疑问请发issues](https://www.gitbook.com/book/javen205/ijpay/details)


### 效果图

**请参考Demo，目前IJPay Demo 提供两个版本 JFinal版本以及Spring Boot版本**

Gitee：[https://gitee.com/Javen205/IJPay-Demo](https://gitee.com/Javen205/IJPay-Demo)

GitHub：[https://github.com/Javen205/IJPay-Demo](https://github.com/Javen205/IJPay-Demo)


**使用Demo之前请熟读以下文章**

[配置应用环境](https://javen205.gitbooks.io/ijpay/content/alipay/alipay-config.html)

[IJPay 支付宝初始化](https://javen205.gitbooks.io/ijpay/content/alipay/alipay-init.html)

### 联系方式

[IJPay交流圈-需要帮助点击这里](https://javen205.gitbooks.io/ijpay/content/contact.html)

[qq0groupsvg]: https://img.shields.io/badge/QQ群-148540125-fba7f9.svg
[qq0group]: http://shang.qq.com/wpa/qunwpa?idkey=5005dbbee62dac64b34fedc9ff73511762da5d02642a1ef526522fb2e07852dd



[licensesvg]: https://img.shields.io/badge/License-Apache--2.0-brightgreen.svg
[license]: https://www.apache.org/licenses/LICENSE-2.0




### 贡献代码

最后如果该库对你有帮助不妨右上角点点Star或者任意打赏支持一下，我更喜欢你 Fork PR 成为项目贡献者 .


### 鸣谢

排名不分先后

- [jfinal](http://git.oschina.net/jfinal/jfinal)
- [jfinal-weixin](http://git.oschina.net/jfinal/jfinal-weixin)
- [zxing](https://github.com/zxing/zxing)
- 感谢第三方公司提供微信商户平台测试

==> IJPay-1.2.2-javadoc.jar: README.md <==
# IJPay

![](assets/img/IJPay-t.png)

[![Gitee star](https://gitee.com/javen205/IJPay/badge/star.svg?theme=white)](https://gitee.com/javen205/IJPay/stargazers)
[![Github start](https://img.shields.io/github/stars/Javen205/IJPay.svg?style=social&label=Stars)](https://github.com/Javen205/IJPay)
[![License][licensesvg]][license]
[![Github downloads](https://img.shields.io/github/downloads/Javen205/IJPay/total.svg)](https://github.com/Javen205/IJPay/releases/latest)
[![IJPay Author](https://img.shields.io/badge/IJPay%20Author-Javen-ff69b4.svg)](http://blog.csdn.net/zyw_java)
[![GitHub release](https://img.shields.io/github/release/Javen205/IJPay.svg)](https://github.com/Javen205/IJPay/release)
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/com.github.javen205/IJPay/badge.svg)](https://maven-badges.herokuapp.com/maven-central/com.github.javen205/IJPay)


**特别说明：** 不依赖任何第三方 mvc 框架，仅仅作为工具使用简单快速完成支付模块的开发，可轻松嵌入到任何系统里。


Gitee：[http://gitee.com/Javen205/IJPay](http://gitee.com/Javen205/IJPay)

GitHub：[https://github.com/Javen205/IJPay](https://github.com/Javen205/IJPay)

APIDOC：[https://apidoc.gitee.com/javen205/IJPay](https://apidoc.gitee.com/javen205/IJPay)



- IJPay是[JPay](https://github.com/Javen205/JPay)后台接口SDK不依赖任何第三方 mvc 框架，仅仅作为工具使用简单快速完成支付模块的开发，可轻松嵌入到任何系统里。
- [JPay](https://github.com/Javen205/JPay) 是简易而不简单的Android 支付SDK，JPay是对微信App支付、支付宝App支付的二次封装,对外提供一个相对简单的接口以及支付结果的回调。
- IOS支付SDK，敬请关注。

### 接入文档

**使用Demo之前请熟读以下文章**

[配置应用环境](https://javen205.gitee.io/ijpay/doc/ijpay/alipay/alipay-config.html)

[IJPay 支付宝初始化](https://javen205.gitee.io/ijpay/doc/ijpay/alipay/alipay-init.html)

[IJPay 接入文档,如有疑问请发issues](https://javen205.gitee.io/IJPay)

### 效果图

**请参考Demo，目前IJPay Demo 提供两个版本 JFinal版本以及Spring Boot版本**

Gitee：[https://gitee.com/Javen205/IJPay-Demo](https://gitee.com/Javen205/IJPay-Demo)

GitHub：[https://github.com/Javen205/IJPay-Demo](https://github.com/Javen205/IJPay-Demo)



### 联系方式

[IJPay交流圈-需要帮助点击这里](https://javen205.gitbooks.io/ijpay/content/contact.html)

[qq0groupsvg]: https://img.shields.io/badge/QQ群-148540125-fba7f9.svg
[qq0group]: http://shang.qq.com/wpa/qunwpa?idkey=5005dbbee62dac64b34fedc9ff73511762da5d02642a1ef526522fb2e07852dd



[licensesvg]: https://img.shields.io/badge/License-Apache--2.0-brightgreen.svg
[license]: https://www.apache.org/licenses/LICENSE-2.0




### 贡献代码

最后如果该库对你有帮助不妨右上角点点Star或者任意打赏支持一下，我更喜欢你 Fork PR 成为项目贡献者 .

## 开源推荐

- `TNW` 极速开发微信公众号：https://gitee.com/javen205/TNW
- SpringBoot 微服务高效开发 `mica` 工具集：https://gitee.com/596392912/mica
- `Avue` 一款基于 vue 可配置化的神奇框架：https://gitee.com/smallweigit/avue
- `pig` 宇宙最强微服务（架构师必备）：https://gitee.com/log4j/pig
- `SpringBlade` 完整的线上解决方案（企业开发必备）：https://gitee.com/smallc/SpringBlade

### 鸣谢

排名不分先后

- [jfinal](http://git.oschina.net/jfinal/jfinal)
- [jfinal-weixin](http://git.oschina.net/jfinal/jfinal-weixin)
- [zxing](https://github.com/zxing/zxing)
- 感谢第三方公司提供微信商户平台测试
